@@ -1,4 +1,8 @@
 from .client import Client
 from .request import RequestClient
 from .statistics import *
-from .utils import *
\ No newline at end of file
+from .utils import *
+
+__version__ = "0.6.2"
+__author__ = "apex2504"
+__license__ = "MIT"
\ No newline at end of file
